# WorkflowErrorCode

A short error code describing the error

## Enum

* `INVALID` (value: `'invalid'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


